zoopb

package module
v0.0.100 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 6, 2025 License: GPL-3.0 Imports: 27 Imported by: 12

README

protobuf definition files for zookeeper

  • experimental. at this point, it's just stubbed in
  • zookeeper is similar to the apache zookeeper project
  • you can use it to maintain the systems in your cluster
  • zookeeper works with virtigo to maintain your private cloud

This also helps generate the files needed in /home/mirrors/debian/dists so one can 'apt update' the package lists.

Documentation

Index

Constants

This section is empty.

Variables

var File_machine_proto protoreflect.FileDescriptor
var File_package_proto protoreflect.FileDescriptor

Functions

func GetDebInfoFields added in v0.0.87

func GetDebInfoFields(pb proto.Message) ([]string, error)

func printDebInfoStrings(pb proto.Message, fallback bool) (string, error) {

Types

type DebInfo added in v0.0.82

type DebInfo struct {
	Package       string `protobuf:"bytes,1,opt,name=Package,proto3" json:"Package,omitempty"`              // `autogenpb:unique` `autogenpb:sort`
	Namespace     string `protobuf:"bytes,2,opt,name=Namespace,proto3" json:"Namespace,omitempty"`          // path to the sources (go.wit.com/apps/zookeeper)
	Version       string `protobuf:"bytes,3,opt,name=Version,proto3" json:"Version,omitempty"`              // version: 0.0.3
	Architecture  string `protobuf:"bytes,4,opt,name=Architecture,proto3" json:"Architecture,omitempty"`    //
	Maintainer    string `protobuf:"bytes,5,opt,name=Maintainer,proto3" json:"Maintainer,omitempty"`        //
	Packager      string `protobuf:"bytes,6,opt,name=Packager,proto3" json:"Packager,omitempty"`            //
	URL           string `protobuf:"bytes,7,opt,name=URL,proto3" json:"URL,omitempty"`                      //
	Homepage      string `protobuf:"bytes,8,opt,name=Homepage,proto3" json:"Homepage,omitempty"`            // deprecate
	Depends       string `protobuf:"bytes,9,opt,name=Depends,proto3" json:"Depends,omitempty"`              //
	PreDepends    string `protobuf:"bytes,10,opt,name=PreDepends,proto3" json:"PreDepends,omitempty"`       //
	BuildDepends  string `protobuf:"bytes,11,opt,name=BuildDepends,proto3" json:"BuildDepends,omitempty"`   //
	Conflicts     string `protobuf:"bytes,12,opt,name=Conflicts,proto3" json:"Conflicts,omitempty"`         //
	Breaks        string `protobuf:"bytes,13,opt,name=Breaks,proto3" json:"Breaks,omitempty"`               //
	Replaces      string `protobuf:"bytes,14,opt,name=Replaces,proto3" json:"Replaces,omitempty"`           //
	Recommends    string `protobuf:"bytes,15,opt,name=Recommends,proto3" json:"Recommends,omitempty"`       //
	Suggests      string `protobuf:"bytes,16,opt,name=Suggests,proto3" json:"Suggests,omitempty"`           //
	MultiArch     string `protobuf:"bytes,17,opt,name=MultiArch,proto3" json:"MultiArch,omitempty"`         //
	Tag           string `protobuf:"bytes,18,opt,name=Tag,proto3" json:"Tag,omitempty"`                     //
	Section       string `protobuf:"bytes,19,opt,name=Section,proto3" json:"Section,omitempty"`             //
	Source        string `protobuf:"bytes,20,opt,name=Source,proto3" json:"Source,omitempty"`               //
	DebCtime      string `protobuf:"bytes,21,opt,name=DebCtime,proto3" json:"DebCtime,omitempty"`           //
	BuildDate     string `protobuf:"bytes,22,opt,name=BuildDate,proto3" json:"BuildDate,omitempty"`         //
	GitHash       string `protobuf:"bytes,23,opt,name=GitHash,proto3" json:"GitHash,omitempty"`             //
	GitDate       string `protobuf:"bytes,24,opt,name=GitDate,proto3" json:"GitDate,omitempty"`             //
	Filename      string `protobuf:"bytes,25,opt,name=Filename,proto3" json:"Filename,omitempty"`           // `autogenpb:unique` `autogenpb:sort`
	Size          string `protobuf:"bytes,26,opt,name=Size,proto3" json:"Size,omitempty"`                   //
	InstalledSize string `protobuf:"bytes,27,opt,name=InstalledSize,proto3" json:"InstalledSize,omitempty"` //
	MD5SUM        string `protobuf:"bytes,28,opt,name=MD5SUM,proto3" json:"MD5SUM,omitempty"`               //
	SHA256        string `protobuf:"bytes,29,opt,name=SHA256,proto3" json:"SHA256,omitempty"`               //
	Description   string `protobuf:"bytes,30,opt,name=Description,proto3" json:"Description,omitempty"`     //
	// contains filtered or unexported fields
}

func (*DebInfo) Descriptor deprecated added in v0.0.82

func (*DebInfo) Descriptor() ([]byte, []int)

Deprecated: Use DebInfo.ProtoReflect.Descriptor instead.

func (*DebInfo) GetArchitecture added in v0.0.82

func (x *DebInfo) GetArchitecture() string

func (*DebInfo) GetBreaks added in v0.0.91

func (x *DebInfo) GetBreaks() string

func (*DebInfo) GetBuildDate added in v0.0.87

func (x *DebInfo) GetBuildDate() string

func (*DebInfo) GetBuildDepends added in v0.0.82

func (x *DebInfo) GetBuildDepends() string

func (*DebInfo) GetConflicts added in v0.0.82

func (x *DebInfo) GetConflicts() string

func (*DebInfo) GetDebCtime added in v0.0.87

func (x *DebInfo) GetDebCtime() string

func (*DebInfo) GetDepends added in v0.0.82

func (x *DebInfo) GetDepends() string

func (*DebInfo) GetDescription added in v0.0.82

func (x *DebInfo) GetDescription() string

func (*DebInfo) GetFilename added in v0.0.82

func (x *DebInfo) GetFilename() string

func (*DebInfo) GetGitDate added in v0.0.87

func (x *DebInfo) GetGitDate() string

func (*DebInfo) GetGitHash added in v0.0.87

func (x *DebInfo) GetGitHash() string

func (*DebInfo) GetHomepage added in v0.0.82

func (x *DebInfo) GetHomepage() string

func (*DebInfo) GetInstalledSize added in v0.0.87

func (x *DebInfo) GetInstalledSize() string

func (*DebInfo) GetMD5SUM added in v0.0.82

func (x *DebInfo) GetMD5SUM() string

func (*DebInfo) GetMaintainer added in v0.0.82

func (x *DebInfo) GetMaintainer() string

func (*DebInfo) GetMultiArch added in v0.0.87

func (x *DebInfo) GetMultiArch() string

func (*DebInfo) GetNamespace added in v0.0.82

func (x *DebInfo) GetNamespace() string

func (*DebInfo) GetPackage added in v0.0.82

func (x *DebInfo) GetPackage() string

func (*DebInfo) GetPackager added in v0.0.82

func (x *DebInfo) GetPackager() string

func (*DebInfo) GetPreDepends added in v0.0.87

func (x *DebInfo) GetPreDepends() string

func (*DebInfo) GetRecommends added in v0.0.91

func (x *DebInfo) GetRecommends() string

func (*DebInfo) GetReplaces added in v0.0.91

func (x *DebInfo) GetReplaces() string

func (*DebInfo) GetSHA256 added in v0.0.82

func (x *DebInfo) GetSHA256() string

func (*DebInfo) GetSection added in v0.0.87

func (x *DebInfo) GetSection() string

func (*DebInfo) GetSize added in v0.0.82

func (x *DebInfo) GetSize() string

func (*DebInfo) GetSource added in v0.0.82

func (x *DebInfo) GetSource() string

func (*DebInfo) GetSuggests added in v0.0.87

func (x *DebInfo) GetSuggests() string

func (*DebInfo) GetTag added in v0.0.87

func (x *DebInfo) GetTag() string

func (*DebInfo) GetURL added in v0.0.82

func (x *DebInfo) GetURL() string

func (*DebInfo) GetVersion added in v0.0.82

func (x *DebInfo) GetVersion() string

func (*DebInfo) ProtoMessage added in v0.0.82

func (*DebInfo) ProtoMessage()

func (*DebInfo) ProtoReflect added in v0.0.82

func (x *DebInfo) ProtoReflect() protoreflect.Message

func (*DebInfo) Reset added in v0.0.82

func (x *DebInfo) Reset()

func (*DebInfo) String added in v0.0.82

func (x *DebInfo) String() string

type DebInfoScanner added in v0.0.82

type DebInfoScanner struct {
	sync.Mutex
	// contains filtered or unexported fields
}

func (*DebInfoScanner) Next added in v0.0.82

func (it *DebInfoScanner) Next() *DebInfo

Next() returns the next thing in the array

func (*DebInfoScanner) Scan added in v0.0.82

func (it *DebInfoScanner) Scan() bool

type Machine added in v0.0.4

type Machine struct {
	Hostname   string                 `protobuf:"bytes,1,opt,name=hostname,proto3" json:"hostname,omitempty"` // `autogenpb:unique` `autogenpb:sort`
	Memory     int64                  `protobuf:"varint,2,opt,name=memory,proto3" json:"memory,omitempty"`
	Cpus       int64                  `protobuf:"varint,3,opt,name=cpus,proto3" json:"cpus,omitempty"`
	Distro     string                 `protobuf:"bytes,4,opt,name=distro,proto3" json:"distro,omitempty"`
	Packages   *Packages              `protobuf:"bytes,5,opt,name=packages,proto3" json:"packages,omitempty"`
	Laststamp  *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=laststamp,proto3" json:"laststamp,omitempty"` // the last time we heard anything from this machine
	Installed  *Packages              `protobuf:"bytes,7,opt,name=installed,proto3" json:"installed,omitempty"` // packages that are installed
	Available  *Packages              `protobuf:"bytes,8,opt,name=available,proto3" json:"available,omitempty"` // packages that are available
	Wit        *Packages              `protobuf:"bytes,9,opt,name=wit,proto3" json:"wit,omitempty"`             // packages that are available from mirrors.wit.com
	UserAgent  string                 `protobuf:"bytes,10,opt,name=userAgent,proto3" json:"userAgent,omitempty"`
	Uuid       string                 `protobuf:"bytes,11,opt,name=uuid,proto3" json:"uuid,omitempty"`
	Upgrade    bool                   `protobuf:"varint,12,opt,name=upgrade,proto3" json:"upgrade,omitempty"`      // upgrade is needed
	UpgradeCmd string                 `protobuf:"bytes,13,opt,name=upgradeCmd,proto3" json:"upgradeCmd,omitempty"` // upgrade cmd
	// contains filtered or unexported fields
}

func (*Machine) Descriptor deprecated added in v0.0.4

func (*Machine) Descriptor() ([]byte, []int)

Deprecated: Use Machine.ProtoReflect.Descriptor instead.

func (*Machine) FindByPackageName added in v0.0.82

func (m *Machine) FindByPackageName(name string) (*Package, error)

func (*Machine) FindByVersion added in v0.0.50

func (m *Machine) FindByVersion(name string, version string) *Package

looks to see if any package matches a name and version if version == "", return the first name found

func (*Machine) FindInstalledByName added in v0.0.8

func (m *Machine) FindInstalledByName(name string) *Package

this is a work in progress

func (*Machine) FindInstalledPackage added in v0.0.72

func (m *Machine) FindInstalledPackage(check *Package) *Package

func (*Machine) FindVersion added in v0.0.8

func (m *Machine) FindVersion(name string) string

looks to see if any package matches a name and version if version == "", return the first name found

func (*Machine) FormatJSON added in v0.0.11

func (v *Machine) FormatJSON() string

human readable JSON

func (*Machine) FormatTEXT added in v0.0.11

func (v *Machine) FormatTEXT() string

apparently this isn't stable, but it's awesomely better https://protobuf.dev/reference/go/faq/#unstable-text it's brilliant for config files!

func (*Machine) GetAvailable added in v0.0.7

func (x *Machine) GetAvailable() *Packages

func (*Machine) GetCpus added in v0.0.4

func (x *Machine) GetCpus() int64

func (*Machine) GetDistro added in v0.0.4

func (x *Machine) GetDistro() string

func (*Machine) GetHostname added in v0.0.4

func (x *Machine) GetHostname() string

func (*Machine) GetInstalled added in v0.0.7

func (x *Machine) GetInstalled() *Packages

func (*Machine) GetLaststamp added in v0.0.4

func (x *Machine) GetLaststamp() *timestamppb.Timestamp

func (*Machine) GetMemory added in v0.0.4

func (x *Machine) GetMemory() int64

func (*Machine) GetPackages added in v0.0.4

func (x *Machine) GetPackages() *Packages

func (*Machine) GetUpgrade added in v0.0.42

func (x *Machine) GetUpgrade() bool

func (*Machine) GetUpgradeCmd added in v0.0.50

func (x *Machine) GetUpgradeCmd() string

func (*Machine) GetUserAgent added in v0.0.29

func (x *Machine) GetUserAgent() string

func (*Machine) GetUuid added in v0.0.37

func (x *Machine) GetUuid() string

func (*Machine) GetWit added in v0.0.7

func (x *Machine) GetWit() *Packages

func (*Machine) HttpPost added in v0.0.36

func (p *Machine) HttpPost(baseURL string, route string) (*Machine, *httppb.HttpRequest, error)

Marshal protobuf, then http POST, then Unmarshal() to protobuf again

func (*Machine) IsInstalled added in v0.0.8

func (m *Machine) IsInstalled(name string) bool

func (*Machine) Load added in v0.0.76

func (pb *Machine) Load() error

func (*Machine) Marshal added in v0.0.4

func (v *Machine) Marshal() ([]byte, error)

marshal to wire. This is called winning.

func (*Machine) MarshalJSON added in v0.0.7

func (v *Machine) MarshalJSON() ([]byte, error)

marshal json

func (*Machine) PrintInstalledTable added in v0.0.75

func (m *Machine) PrintInstalledTable()

func (*Machine) PrintTable added in v0.0.72

func (m *Machine) PrintTable(pb *Packages)

func (*Machine) ProtoMessage added in v0.0.4

func (*Machine) ProtoMessage()

func (*Machine) ProtoReflect added in v0.0.4

func (x *Machine) ProtoReflect() protoreflect.Message

func (*Machine) Reset added in v0.0.4

func (x *Machine) Reset()

func (*Machine) Save added in v0.0.76

func (pb *Machine) Save() error

func (*Machine) SendReply added in v0.0.60

func (p *Machine) SendReply(w http.ResponseWriter, reqPB *httppb.HttpRequest) error

func (*Machine) SinceLastUpdate added in v0.0.48

func (m *Machine) SinceLastUpdate() time.Duration

func (*Machine) String added in v0.0.4

func (x *Machine) String() string

func (*Machine) Unmarshal added in v0.0.4

func (v *Machine) Unmarshal(data []byte) error

unmarshal from wire. You have won.

func (*Machine) UnmarshalJSON added in v0.0.11

func (v *Machine) UnmarshalJSON(data []byte) error

unmarshal json

func (*Machine) UnmarshalTEXT added in v0.0.11

func (v *Machine) UnmarshalTEXT(data []byte) error

unmarshalTEXT. This reads the .text config file back in after the user edits it

func (*Machine) WillUpgrade added in v0.0.72

func (m *Machine) WillUpgrade(p *Package) bool

true if the package 'p' is newer than the installed package

type MachineFunc added in v0.0.70

type MachineFunc struct {
	Custom func(*Machine)
	Width  int
	Attr   *guipb.ColAttr
	Header *guipb.Widget
	// contains filtered or unexported fields
}

func (*MachineFunc) SetTitle added in v0.0.70

func (sf *MachineFunc) SetTitle(title string)

type MachineScanner added in v0.0.54

type MachineScanner struct {
	sync.Mutex
	// contains filtered or unexported fields
}

func (*MachineScanner) Next added in v0.0.54

func (it *MachineScanner) Next() *Machine

Next() returns the next thing in the array

func (*MachineScanner) Scan added in v0.0.54

func (it *MachineScanner) Scan() bool

type Machines added in v0.0.4

type Machines struct {
	Uuid     string     `protobuf:"bytes,1,opt,name=uuid,proto3" json:"uuid,omitempty"`       // `autogenpb:uuid:b57e7fac-a8fc-4949-9d50-fa38312dec87`
	Version  string     `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"` // `autogenpb:version:v0.0.1`
	Machines []*Machine `protobuf:"bytes,3,rep,name=machines,proto3" json:"machines,omitempty"`
	Filename string     `protobuf:"bytes,4,opt,name=filename,proto3" json:"filename,omitempty"` // `autogenpb:save` -- this enables autogenerated pb.Load() and pb.Save()
	// contains filtered or unexported fields
}

func NewMachines added in v0.0.23

func NewMachines() *Machines

func (*Machines) All added in v0.0.4

func (x *Machines) All() *MachineScanner

func (*Machines) Append added in v0.0.4

func (x *Machines) Append(y *Machine)

a Append() shortcut (that does Clone() with a mutex) notsure if it really works doesn't allow nil

func (*Machines) AppendByHostname added in v0.0.23

func (x *Machines) AppendByHostname(y *Machine) bool

func (*Machines) Clone added in v0.0.83

func (x *Machines) Clone(y *Machine) *Machine

a Clone() shortcut (with a mutex). notsure if it really works

func (*Machines) CloneByHostname added in v0.0.83

func (x *Machines) CloneByHostname(y *Machine) bool

func (*Machines) Delete added in v0.0.23

func (x *Machines) Delete(y *Machine) bool

func (*Machines) DeleteByHostname added in v0.0.11

func (x *Machines) DeleteByHostname(s string) bool

func (*Machines) Descriptor deprecated added in v0.0.4

func (*Machines) Descriptor() ([]byte, []int)

Deprecated: Use Machines.ProtoReflect.Descriptor instead.

func (*Machines) FindByHostname added in v0.0.11

func (x *Machines) FindByHostname(s string) *Machine

lookup a Machines by the Hostname

func (*Machines) FormatJSON added in v0.0.11

func (v *Machines) FormatJSON() string

human readable JSON

func (*Machines) FormatTEXT added in v0.0.11

func (v *Machines) FormatTEXT() string

apparently this isn't stable, but it's awesomely better https://protobuf.dev/reference/go/faq/#unstable-text it's brilliant for config files!

func (*Machines) GetFilename added in v0.0.74

func (x *Machines) GetFilename() string

func (*Machines) GetMachines added in v0.0.4

func (x *Machines) GetMachines() []*Machine

func (*Machines) GetUuid added in v0.0.4

func (x *Machines) GetUuid() string

func (*Machines) GetVersion added in v0.0.4

func (x *Machines) GetVersion() string

func (*Machines) HttpPost added in v0.0.60

func (p *Machines) HttpPost(baseURL string, route string) (*Machines, *httppb.HttpRequest, error)

Marshal protobuf, then http POST, then Unmarshal() to protobuf again

func (*Machines) InsertByHostname added in v0.0.47

func (x *Machines) InsertByHostname(y string) *Machine

returns a Machine if Hostname matches, otherwise create

func (*Machines) IterAll added in v0.0.47

func (x *Machines) IterAll() iter.Seq[*Machine]

Iterate 'for x := range' syntax using the awesome golang 1.24 'iter'

func (*Machines) IterByHostname added in v0.0.47

func (x *Machines) IterByHostname() iter.Seq[*Machine]

'for x := range' syntax using the awesome golang 1.24 'iter'

func (*Machines) Len added in v0.0.4

func (x *Machines) Len() int

func (*Machines) Load added in v0.0.74

func (pb *Machines) Load() error

func (*Machines) Marshal added in v0.0.6

func (v *Machines) Marshal() ([]byte, error)

marshal to wire. This is called winning.

func (*Machines) MarshalJSON added in v0.0.11

func (v *Machines) MarshalJSON() ([]byte, error)

marshal json

func (*Machines) NewTable added in v0.0.30

func (x *Machines) NewTable(title string) *MachinesTable

func (*Machines) ProtoMessage added in v0.0.4

func (*Machines) ProtoMessage()

func (*Machines) ProtoReflect added in v0.0.4

func (x *Machines) ProtoReflect() protoreflect.Message

func (*Machines) Reset added in v0.0.4

func (x *Machines) Reset()

func (*Machines) Save added in v0.0.74

func (pb *Machines) Save() error

func (*Machines) SendReply added in v0.0.60

func (p *Machines) SendReply(w http.ResponseWriter, reqPB *httppb.HttpRequest) error

func (*Machines) SortByHostname added in v0.0.11

func (x *Machines) SortByHostname() *MachineScanner

func (*Machines) SortHostname added in v0.0.79

func (pb *Machines) SortHostname()

func (*Machines) String added in v0.0.4

func (x *Machines) String() string

func (*Machines) Unmarshal added in v0.0.6

func (v *Machines) Unmarshal(data []byte) error

unmarshal from wire. You have won.

func (*Machines) UnmarshalJSON added in v0.0.11

func (v *Machines) UnmarshalJSON(data []byte) error

unmarshal json

func (*Machines) UnmarshalTEXT added in v0.0.11

func (v *Machines) UnmarshalTEXT(data []byte) error

unmarshalTEXT. This reads the .text config file back in after the user edits it

type MachinesScanner added in v0.0.54

type MachinesScanner struct {
	sync.Mutex
	// contains filtered or unexported fields
}

func (*MachinesScanner) Next added in v0.0.54

func (it *MachinesScanner) Next() *Machines

Next() returns the next thing in the array

func (*MachinesScanner) Scan added in v0.0.54

func (it *MachinesScanner) Scan() bool

type MachinesTable added in v0.0.30

type MachinesTable struct {
	Funcs      []*MachineFunc
	CustomFunc func(*Machine)
	// contains filtered or unexported fields
}

func (*MachinesTable) AddButtonFunc added in v0.0.41

func (t *MachinesTable) AddButtonFunc(title string, f func(*Machine) string) *MachineFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*MachinesTable) AddCpus added in v0.0.31

func (t *MachinesTable) AddCpus() *MachineFunc

func (*MachinesTable) AddDistro added in v0.0.32

func (t *MachinesTable) AddDistro() *MachineFunc

func (*MachinesTable) AddHostname added in v0.0.30

func (t *MachinesTable) AddHostname() *MachineFunc

func (*MachinesTable) AddIntFunc added in v0.0.31

func (t *MachinesTable) AddIntFunc(title string, f func(*Machine) int) *MachineFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*MachinesTable) AddMemory added in v0.0.31

func (t *MachinesTable) AddMemory() *MachineFunc

func (*MachinesTable) AddStringFunc added in v0.0.30

func (t *MachinesTable) AddStringFunc(title string, f func(*Machine) string) *MachineFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*MachinesTable) AddTimeFunc added in v0.0.31

func (t *MachinesTable) AddTimeFunc(title string, f func(*Machine) time.Time) *MachineFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*MachinesTable) AddUpgradeCmd added in v0.0.50

func (t *MachinesTable) AddUpgradeCmd() *MachineFunc

func (*MachinesTable) AddUserAgent added in v0.0.32

func (t *MachinesTable) AddUserAgent() *MachineFunc

func (*MachinesTable) AddUuid added in v0.0.37

func (t *MachinesTable) AddUuid() *MachineFunc

func (*MachinesTable) Custom added in v0.0.41

func (mt *MachinesTable) Custom(f func(*Machine))

func (*MachinesTable) Delete added in v0.0.41

func (mt *MachinesTable) Delete()

func (*MachinesTable) GetUuid added in v0.0.41

func (mt *MachinesTable) GetUuid() string

func (*MachinesTable) MakeTable added in v0.0.30

func (mt *MachinesTable) MakeTable()

func (*MachinesTable) NewUuid added in v0.0.41

func (mt *MachinesTable) NewUuid()

func (*MachinesTable) PrintTable added in v0.0.67

func (t *MachinesTable) PrintTable()

formats & prints the table as text to Stdout. a real timesaver!

func (*MachinesTable) SetParent added in v0.0.37

func (mt *MachinesTable) SetParent(p *gui.Node)

func (*MachinesTable) ShowTable added in v0.0.30

func (mt *MachinesTable) ShowTable()

type Package added in v0.0.4

type Package struct {
	Package      string                 `protobuf:"bytes,1,opt,name=Package,proto3" json:"Package,omitempty"`           // `autogenpb:unique` `autogenpb:sort`
	Filename     string                 `protobuf:"bytes,2,opt,name=Filename,proto3" json:"Filename,omitempty"`         // `autogenpb:unique` `autogenpb:sort`
	Namespace    string                 `protobuf:"bytes,3,opt,name=Namespace,proto3" json:"Namespace,omitempty"`       // namespace path to the sources (go.wit.com/apps/zookeeper)
	Version      string                 `protobuf:"bytes,4,opt,name=Version,proto3" json:"Version,omitempty"`           //
	Architecture string                 `protobuf:"bytes,5,opt,name=Architecture,proto3" json:"Architecture,omitempty"` //
	DebInfo      *DebInfo               `protobuf:"bytes,6,opt,name=debInfo,proto3" json:"debInfo,omitempty"`           // the information given by "dpkg -I pingus.deb"
	Installed    bool                   `protobuf:"varint,7,opt,name=installed,proto3" json:"installed,omitempty"`      // if installed on your machine, this should be set to true
	Ctime        *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=ctime,proto3" json:"ctime,omitempty"`               // the ctime of the file on the mirrors
	BuildDate    *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=buildDate,proto3" json:"buildDate,omitempty"`       // when the package was built
	GitDate      *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=gitDate,proto3" json:"gitDate,omitempty"`          // the tiem of the last git commit
	GitHash      string                 `protobuf:"bytes,11,opt,name=gitHash,proto3" json:"gitHash,omitempty"`          // the git hash it was built from
	Custom       map[string]string      ``                                                                              // for custom strings
	/* 154-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*Package) Descriptor deprecated added in v0.0.4

func (*Package) Descriptor() ([]byte, []int)

Deprecated: Use Package.ProtoReflect.Descriptor instead.

func (*Package) GetAge added in v0.0.96

func (p *Package) GetAge() *time.Time

func (*Package) GetArchitecture added in v0.0.79

func (x *Package) GetArchitecture() string

func (*Package) GetBuildCount added in v0.0.95

func (p *Package) GetBuildCount() int

func (*Package) GetBuildDate added in v0.0.81

func (x *Package) GetBuildDate() *timestamppb.Timestamp

func (*Package) GetCtime added in v0.0.79

func (x *Package) GetCtime() *timestamppb.Timestamp

func (*Package) GetCustom added in v0.0.82

func (x *Package) GetCustom() map[string]string

func (*Package) GetDebInfo added in v0.0.82

func (x *Package) GetDebInfo() *DebInfo

func (*Package) GetDebianControlFile added in v0.0.86

func (pb *Package) GetDebianControlFile() (string, error)

func (*Package) GetFilename added in v0.0.79

func (x *Package) GetFilename() string

func (*Package) GetGitDate added in v0.0.81

func (x *Package) GetGitDate() *timestamppb.Timestamp

func (*Package) GetGitHash added in v0.0.82

func (x *Package) GetGitHash() string

func (*Package) GetInstalled added in v0.0.7

func (x *Package) GetInstalled() bool

func (*Package) GetNamespace added in v0.0.80

func (x *Package) GetNamespace() string

func (*Package) GetPackage added in v0.0.79

func (x *Package) GetPackage() string

func (*Package) GetSmartVersion added in v0.0.96

func (p *Package) GetSmartVersion() string

func (*Package) GetVersion added in v0.0.4

func (x *Package) GetVersion() string

func (*Package) Print added in v0.0.84

func (pb *Package) Print() (string, error)

func (*Package) ProtoMessage added in v0.0.4

func (*Package) ProtoMessage()

func (*Package) ProtoReflect added in v0.0.4

func (x *Package) ProtoReflect() protoreflect.Message

func (*Package) Reset added in v0.0.4

func (x *Package) Reset()

func (*Package) String added in v0.0.4

func (x *Package) String() string

type PackageFunc added in v0.0.70

type PackageFunc struct {
	Custom func(*Package)
	Width  int
	Attr   *guipb.ColAttr
	Header *guipb.Widget
	// contains filtered or unexported fields
}

func (*PackageFunc) SetTitle added in v0.0.70

func (sf *PackageFunc) SetTitle(title string)

type PackageScanner added in v0.0.54

type PackageScanner struct {
	sync.Mutex
	// contains filtered or unexported fields
}

func (*PackageScanner) Next added in v0.0.54

func (it *PackageScanner) Next() *Package

Next() returns the next thing in the array

func (*PackageScanner) Scan added in v0.0.54

func (it *PackageScanner) Scan() bool

type Packages added in v0.0.4

type Packages struct {
	Uuid     string     `protobuf:"bytes,1,opt,name=uuid,proto3" json:"uuid,omitempty"`       // `autogenpb:uuid:2f26cc03-ea30-4481-a333-ad0acc86e1d3`
	Version  string     `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"` // `autogenpb:version:v0.0.6`
	Packages []*Package `protobuf:"bytes,3,rep,name=packages,proto3" json:"packages,omitempty"`
	Filename string     `protobuf:"bytes,4,opt,name=filename,proto3" json:"filename,omitempty"` // `autogenpb:save` -- this enables autogenerated pb.Load() and pb.Save()
	Changed  bool       `protobuf:"varint,5,opt,name=changed,proto3" json:"changed,omitempty"`  // only writes to disk on Save() if changed == true
	GpgKeyID string     `protobuf:"bytes,6,opt,name=gpgKeyID,proto3" json:"gpgKeyID,omitempty"` // the gpg key used to sign the debian mirror Package files
	BaseDir  string     `protobuf:"bytes,7,opt,name=baseDir,proto3" json:"baseDir,omitempty"`   // where your mirrors repo starts "/home/mirrors/debian"
	Errors   []string   `protobuf:"bytes,8,rep,name=Errors,proto3" json:"Errors,omitempty"`     // expirement. probably a dumb one
	// contains filtered or unexported fields
}

func NewPackages added in v0.0.23

func NewPackages() *Packages

func (*Packages) All added in v0.0.4

func (x *Packages) All() *PackageScanner

func (*Packages) Append added in v0.0.4

func (x *Packages) Append(y *Package)

a Append() shortcut (that does Clone() with a mutex) notsure if it really works doesn't allow nil

func (*Packages) AppendByFilename added in v0.0.81

func (x *Packages) AppendByFilename(y *Package) bool

func (*Packages) AppendByPackage added in v0.0.81

func (x *Packages) AppendByPackage(y *Package) bool

func (*Packages) Clone added in v0.0.83

func (x *Packages) Clone(y *Package) *Package

a Clone() shortcut (with a mutex). notsure if it really works

func (*Packages) CloneByFilename added in v0.0.83

func (x *Packages) CloneByFilename(y *Package) bool

func (*Packages) CloneByPackage added in v0.0.86

func (x *Packages) CloneByPackage(y *Package) bool

func (*Packages) Delete added in v0.0.23

func (x *Packages) Delete(y *Package) bool

func (*Packages) DeleteByFilename added in v0.0.81

func (x *Packages) DeleteByFilename(s string) bool

func (*Packages) DeleteByPackage added in v0.0.81

func (x *Packages) DeleteByPackage(s string) bool

func (*Packages) Descriptor deprecated added in v0.0.4

func (*Packages) Descriptor() ([]byte, []int)

Deprecated: Use Packages.ProtoReflect.Descriptor instead.

func (*Packages) FindByFilename added in v0.0.81

func (x *Packages) FindByFilename(s string) *Package

lookup a Packages by the Filename

func (*Packages) FindByPackage added in v0.0.81

func (x *Packages) FindByPackage(s string) *Package

lookup a Packages by the Package

func (*Packages) FindByPackageName added in v0.0.82

func (all *Packages) FindByPackageName(name string) (*Package, error)

used when you want to inforce the protobuf only has one package per name

func (*Packages) FormatJSON added in v0.0.4

func (v *Packages) FormatJSON() string

human readable JSON

func (*Packages) FormatTEXT added in v0.0.4

func (v *Packages) FormatTEXT() string

apparently this isn't stable, but it's awesomely better https://protobuf.dev/reference/go/faq/#unstable-text it's brilliant for config files!

func (*Packages) GetBaseDir added in v0.0.82

func (x *Packages) GetBaseDir() string

func (*Packages) GetChanged added in v0.0.81

func (x *Packages) GetChanged() bool

func (*Packages) GetErrors added in v0.0.82

func (x *Packages) GetErrors() []string

func (*Packages) GetFilename added in v0.0.74

func (x *Packages) GetFilename() string

func (*Packages) GetGpgKeyID added in v0.0.82

func (x *Packages) GetGpgKeyID() string

func (*Packages) GetPackages added in v0.0.4

func (x *Packages) GetPackages() []*Package

func (*Packages) GetUuid added in v0.0.4

func (x *Packages) GetUuid() string

func (*Packages) GetVersion added in v0.0.4

func (x *Packages) GetVersion() string

func (*Packages) HttpPost added in v0.0.70

func (p *Packages) HttpPost(baseURL string, route string) (*Packages, *httppb.HttpRequest, error)

Marshal protobuf, then http POST, then Unmarshal() to protobuf again

func (*Packages) InsertByFilename added in v0.0.81

func (x *Packages) InsertByFilename(y string) *Package

returns a Package if Filename matches, otherwise create

func (*Packages) InsertByPackage added in v0.0.81

func (x *Packages) InsertByPackage(y string) *Package

returns a Package if Package matches, otherwise create

func (*Packages) IterAll added in v0.0.47

func (x *Packages) IterAll() iter.Seq[*Package]

Iterate 'for x := range' syntax using the awesome golang 1.24 'iter'

func (*Packages) IterByFilename added in v0.0.81

func (x *Packages) IterByFilename() iter.Seq[*Package]

'for x := range' syntax using the awesome golang 1.24 'iter'

func (*Packages) IterByPackage added in v0.0.81

func (x *Packages) IterByPackage() iter.Seq[*Package]

'for x := range' syntax using the awesome golang 1.24 'iter'

func (*Packages) Len added in v0.0.4

func (x *Packages) Len() int

func (*Packages) Load added in v0.0.74

func (pb *Packages) Load() error

func (*Packages) MakeDefaultTable added in v0.0.81

func (pb *Packages) MakeDefaultTable() *PackagesTable

func (*Packages) Marshal added in v0.0.4

func (v *Packages) Marshal() ([]byte, error)

marshal to wire. This is called winning.

func (*Packages) MarshalJSON added in v0.0.4

func (v *Packages) MarshalJSON() ([]byte, error)

marshal json

func (*Packages) NewTable added in v0.0.70

func (x *Packages) NewTable(title string) *PackagesTable

func (*Packages) PrintTable added in v0.0.70

func (pb *Packages) PrintTable() string

func (*Packages) ProtoMessage added in v0.0.4

func (*Packages) ProtoMessage()

func (*Packages) ProtoReflect added in v0.0.4

func (x *Packages) ProtoReflect() protoreflect.Message

func (*Packages) Reset added in v0.0.4

func (x *Packages) Reset()

func (*Packages) Save added in v0.0.74

func (pb *Packages) Save() error

func (*Packages) SendReply added in v0.0.70

func (p *Packages) SendReply(w http.ResponseWriter, reqPB *httppb.HttpRequest) error

func (*Packages) SortByFilename added in v0.0.81

func (x *Packages) SortByFilename() *PackageScanner

func (*Packages) SortByPackage added in v0.0.81

func (x *Packages) SortByPackage() *PackageScanner

func (*Packages) SortFilename added in v0.0.81

func (pb *Packages) SortFilename()

func (*Packages) SortPackage added in v0.0.81

func (pb *Packages) SortPackage()

func (*Packages) String added in v0.0.4

func (x *Packages) String() string

func (*Packages) Unmarshal added in v0.0.4

func (v *Packages) Unmarshal(data []byte) error

unmarshal from wire. You have won.

func (*Packages) UnmarshalJSON added in v0.0.4

func (v *Packages) UnmarshalJSON(data []byte) error

unmarshal json

func (*Packages) UnmarshalTEXT added in v0.0.11

func (v *Packages) UnmarshalTEXT(data []byte) error

unmarshalTEXT. This reads the .text config file back in after the user edits it

type PackagesScanner added in v0.0.54

type PackagesScanner struct {
	sync.Mutex
	// contains filtered or unexported fields
}

func (*PackagesScanner) Next added in v0.0.54

func (it *PackagesScanner) Next() *Packages

Next() returns the next thing in the array

func (*PackagesScanner) Scan added in v0.0.54

func (it *PackagesScanner) Scan() bool

type PackagesTable added in v0.0.70

type PackagesTable struct {
	Funcs      []*PackageFunc
	CustomFunc func(*Package)
	// contains filtered or unexported fields
}

func (*PackagesTable) AddArchitecture added in v0.0.79

func (t *PackagesTable) AddArchitecture() *PackageFunc

func (*PackagesTable) AddBuildCount added in v0.0.95

func (t *PackagesTable) AddBuildCount() *PackageFunc

func (*PackagesTable) AddButtonFunc added in v0.0.70

func (t *PackagesTable) AddButtonFunc(title string, f func(*Package) string) *PackageFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*PackagesTable) AddFilename added in v0.0.79

func (t *PackagesTable) AddFilename() *PackageFunc

func (*PackagesTable) AddGitHash added in v0.0.87

func (t *PackagesTable) AddGitHash() *PackageFunc

func (*PackagesTable) AddIntFunc added in v0.0.70

func (t *PackagesTable) AddIntFunc(title string, f func(*Package) int) *PackageFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*PackagesTable) AddNamespace added in v0.0.80

func (t *PackagesTable) AddNamespace() *PackageFunc

func (*PackagesTable) AddPackage added in v0.0.79

func (t *PackagesTable) AddPackage() *PackageFunc

func (*PackagesTable) AddSmartVersion added in v0.0.89

func (t *PackagesTable) AddSmartVersion() *PackageFunc

func (*PackagesTable) AddStringFunc added in v0.0.70

func (t *PackagesTable) AddStringFunc(title string, f func(*Package) string) *PackageFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*PackagesTable) AddTimeFunc added in v0.0.70

func (t *PackagesTable) AddTimeFunc(title string, f func(*Package) time.Time) *PackageFunc

force the application to choose the type of data. this allows the GUI plugin to be smarter

func (*PackagesTable) AddVersion added in v0.0.70

func (t *PackagesTable) AddVersion() *PackageFunc

func (*PackagesTable) Custom added in v0.0.70

func (mt *PackagesTable) Custom(f func(*Package))

func (*PackagesTable) Delete added in v0.0.70

func (mt *PackagesTable) Delete()

func (*PackagesTable) GetUuid added in v0.0.70

func (mt *PackagesTable) GetUuid() string

func (*PackagesTable) MakeTable added in v0.0.70

func (mt *PackagesTable) MakeTable()

func (*PackagesTable) NewUuid added in v0.0.70

func (mt *PackagesTable) NewUuid()

func (*PackagesTable) PrintTable added in v0.0.70

func (t *PackagesTable) PrintTable()

formats & prints the table as text to Stdout. a real timesaver!

func (*PackagesTable) SetParent added in v0.0.70

func (mt *PackagesTable) SetParent(p *gui.Node)

func (*PackagesTable) ShowTable added in v0.0.70

func (mt *PackagesTable) ShowTable()

Jump to