Documentation
¶
Index ¶
- Variables
- type AnyCol
- func (*AnyCol) Descriptor() ([]byte, []int)deprecated
- func (x *AnyCol) GetAttr() *ColAttr
- func (x *AnyCol) GetHeader() *Widget
- func (x *AnyCol) GetVals() []*anypb.Any
- func (x *AnyCol) GetWidgets() []*Widget
- func (*AnyCol) ProtoMessage()
- func (x *AnyCol) ProtoReflect() protoreflect.Message
- func (x *AnyCol) Reset()
- func (x *AnyCol) String() string
- type AnyColScanner
- type ColAttr
- func (*ColAttr) Descriptor() ([]byte, []int)deprecated
- func (x *ColAttr) GetClick() bool
- func (x *ColAttr) GetPad() int32
- func (x *ColAttr) GetType() ColAttr_VarType
- func (x *ColAttr) GetWidth() int32
- func (*ColAttr) ProtoMessage()
- func (x *ColAttr) ProtoReflect() protoreflect.Message
- func (x *ColAttr) Reset()
- func (x *ColAttr) String() string
- type ColAttrScanner
- type ColAttr_VarType
- func (ColAttr_VarType) Descriptor() protoreflect.EnumDescriptor
- func (x ColAttr_VarType) Enum() *ColAttr_VarType
- func (ColAttr_VarType) EnumDescriptor() ([]byte, []int)deprecated
- func (x ColAttr_VarType) Number() protoreflect.EnumNumber
- func (x ColAttr_VarType) String() string
- func (ColAttr_VarType) Type() protoreflect.EnumType
- type Location
- type LocationScanner
- type Size
- type SizeScanner
- type Table
- func (pb *Table) Custom(w *Widget)
- func (*Table) Descriptor() ([]byte, []int)deprecated
- func (v *Table) FormatJSON() string
- func (v *Table) FormatTEXT() string
- func (x *Table) GetAnyCols() []*AnyCol
- func (x *Table) GetGrid() *Widget
- func (x *Table) GetParent() *Widget
- func (x *Table) GetTitle() string
- func (x *Table) GetUuid() string
- func (v *Table) Marshal() ([]byte, error)
- func (v *Table) MarshalJSON() ([]byte, error)
- func (*Table) ProtoMessage()
- func (x *Table) ProtoReflect() protoreflect.Message
- func (pb *Table) RegisterCustom(f func(*Widget))
- func (x *Table) Reset()
- func (x *Table) String() string
- func (v *Table) Unmarshal(data []byte) error
- func (v *Table) UnmarshalJSON(data []byte) error
- func (v *Table) UnmarshalTEXT(data []byte) error
- type TableScanner
- type Tables
- func (x *Tables) All() *TableScanner
- func (x *Tables) Append(y *Table)
- func (x *Tables) Clone(y *Table) *Table
- func (pb *Tables) Custom(w *Widget)
- func (x *Tables) Delete(y *Table) bool
- func (*Tables) Descriptor() ([]byte, []int)deprecated
- func (v *Tables) FormatJSON() string
- func (v *Tables) FormatTEXT() string
- func (x *Tables) GetTables() []*Table
- func (x *Tables) GetUuid() string
- func (x *Tables) GetVersion() string
- func (x *Tables) IterAll() iter.Seq[*Table]
- func (x *Tables) Len() int
- func (v *Tables) Marshal() ([]byte, error)
- func (v *Tables) MarshalJSON() ([]byte, error)
- func (*Tables) ProtoMessage()
- func (x *Tables) ProtoReflect() protoreflect.Message
- func (x *Tables) Reset()
- func (x *Tables) String() string
- func (v *Tables) Unmarshal(data []byte) error
- func (v *Tables) UnmarshalJSON(data []byte) error
- func (v *Tables) UnmarshalTEXT(data []byte) error
- type TablesScanner
- type Widget
- func (*Widget) Descriptor() ([]byte, []int)deprecated
- func (x *Widget) GetButton() *Widget_Standard
- func (x *Widget) GetCheckbox() *Widget_Standard
- func (x *Widget) GetChildren() []*Widget
- func (x *Widget) GetId() int64
- func (x *Widget) GetLocation() *Location
- func (x *Widget) GetName() string
- func (x *Widget) GetRoot() *Widget_Internal
- func (x *Widget) GetTab() *Widget_Standard
- func (x *Widget) GetTablePB() []byte
- func (x *Widget) GetTextbox() *Widget_Standard
- func (m *Widget) GetType() isWidget_Type
- func (x *Widget) GetType_() WidgetType
- func (x *Widget) GetVal() *anypb.Any
- func (x *Widget) GetWindow() *Widget_Standard
- func (x *Widget) IsButton() bool
- func (*Widget) ProtoMessage()
- func (x *Widget) ProtoReflect() protoreflect.Message
- func (x *Widget) Reset()
- func (x *Widget) String() string
- type WidgetScanner
- type WidgetType
- type Widget_Button
- type Widget_Checkbox
- type Widget_Internal
- type Widget_Root
- type Widget_Standard
- func (*Widget_Standard) Descriptor() ([]byte, []int)deprecated
- func (x *Widget_Standard) GetName() string
- func (x *Widget_Standard) GetProgName() string
- func (*Widget_Standard) ProtoMessage()
- func (x *Widget_Standard) ProtoReflect() protoreflect.Message
- func (x *Widget_Standard) Reset()
- func (x *Widget_Standard) String() string
- type Widget_Tab
- type Widget_TablePB
- type Widget_Textbox
- type Widget_Window
- type Widgets
- func (x *Widgets) All() *WidgetScanner
- func (x *Widgets) Append(y *Widget)
- func (x *Widgets) Clone(y *Widget) *Widget
- func (x *Widgets) Delete(y *Widget) bool
- func (*Widgets) Descriptor() ([]byte, []int)deprecated
- func (v *Widgets) FormatJSON() string
- func (v *Widgets) FormatTEXT() string
- func (x *Widgets) GetTree() *Widget
- func (x *Widgets) GetUuid() string
- func (x *Widgets) GetVersion() string
- func (x *Widgets) GetWidgets() []*Widget
- func (x *Widgets) IterAll() iter.Seq[*Widget]
- func (x *Widgets) Len() int
- func (v *Widgets) Marshal() ([]byte, error)
- func (v *Widgets) MarshalJSON() ([]byte, error)
- func (*Widgets) ProtoMessage()
- func (x *Widgets) ProtoReflect() protoreflect.Message
- func (x *Widgets) Reset()
- func (x *Widgets) String() string
- func (v *Widgets) Unmarshal(data []byte) error
- func (v *Widgets) UnmarshalJSON(data []byte) error
- func (v *Widgets) UnmarshalTEXT(data []byte) error
- type WidgetsScanner
Constants ¶
This section is empty.
Variables ¶
var ( ColAttr_VarType_name = map[int32]string{ 0: "ANY", 1: "INT", 2: "STRING", 3: "TIME", 4: "DURATION", 5: "BYTES", } ColAttr_VarType_value = map[string]int32{ "ANY": 0, "INT": 1, "STRING": 2, "TIME": 3, "DURATION": 4, "BYTES": 5, } )
Enum value maps for ColAttr_VarType.
var ( WidgetType_name = map[int32]string{ 0: "Root", 1: "Flag", 2: "Window", 3: "Tab", 4: "Box", 5: "Group", 6: "Grid", 7: "Button", 8: "Checkbox", 9: "Dropdown", 10: "Combobox", 11: "Label", 12: "Textbox", 13: "TablePB", } WidgetType_value = map[string]int32{ "Root": 0, "Flag": 1, "Window": 2, "Tab": 3, "Box": 4, "Group": 5, "Grid": 6, "Button": 7, "Checkbox": 8, "Dropdown": 9, "Combobox": 10, "Label": 11, "Textbox": 12, "TablePB": 13, } )
Enum value maps for WidgetType.
var File_table_proto protoreflect.FileDescriptor
var File_widget_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AnyCol ¶ added in v0.0.15
type AnyCol struct {
Header *Widget `protobuf:"bytes,1,opt,name=header,proto3" json:"header,omitempty"`
Widgets []*Widget `protobuf:"bytes,2,rep,name=widgets,proto3" json:"widgets,omitempty"`
Attr *ColAttr `protobuf:"bytes,3,opt,name=attr,proto3" json:"attr,omitempty"`
Vals []*anypb.Any `protobuf:"bytes,4,rep,name=vals,proto3" json:"vals,omitempty"` // deprecate
// contains filtered or unexported fields
}
func (*AnyCol) Descriptor
deprecated
added in
v0.0.15
func (*AnyCol) GetWidgets ¶ added in v0.0.15
func (*AnyCol) ProtoMessage ¶ added in v0.0.15
func (*AnyCol) ProtoMessage()
func (*AnyCol) ProtoReflect ¶ added in v0.0.15
func (x *AnyCol) ProtoReflect() protoreflect.Message
type AnyColScanner ¶ added in v0.0.15
func (*AnyColScanner) Next ¶ added in v0.0.15
func (it *AnyColScanner) Next() *AnyCol
Next() returns the next thing in the array
func (*AnyColScanner) Scan ¶ added in v0.0.15
func (it *AnyColScanner) Scan() bool
type ColAttr ¶ added in v0.0.15
type ColAttr struct {
Pad int32 `protobuf:"varint,1,opt,name=pad,proto3" json:"pad,omitempty"`
Width int32 `protobuf:"varint,2,opt,name=width,proto3" json:"width,omitempty"`
Click bool `protobuf:"varint,3,opt,name=click,proto3" json:"click,omitempty"`
Type ColAttr_VarType `protobuf:"varint,4,opt,name=type,proto3,enum=gitpb.ColAttr_VarType" json:"type,omitempty"`
// contains filtered or unexported fields
}
func (*ColAttr) Descriptor
deprecated
added in
v0.0.15
func (*ColAttr) GetType ¶ added in v0.0.15
func (x *ColAttr) GetType() ColAttr_VarType
func (*ColAttr) ProtoMessage ¶ added in v0.0.15
func (*ColAttr) ProtoMessage()
func (*ColAttr) ProtoReflect ¶ added in v0.0.15
func (x *ColAttr) ProtoReflect() protoreflect.Message
type ColAttrScanner ¶ added in v0.0.15
func (*ColAttrScanner) Next ¶ added in v0.0.15
func (it *ColAttrScanner) Next() *ColAttr
Next() returns the next thing in the array
func (*ColAttrScanner) Scan ¶ added in v0.0.15
func (it *ColAttrScanner) Scan() bool
type ColAttr_VarType ¶ added in v0.0.15
type ColAttr_VarType int32
const ( ColAttr_ANY ColAttr_VarType = 0 ColAttr_INT ColAttr_VarType = 1 ColAttr_STRING ColAttr_VarType = 2 ColAttr_TIME ColAttr_VarType = 3 ColAttr_DURATION ColAttr_VarType = 4 ColAttr_BYTES ColAttr_VarType = 5 )
func (ColAttr_VarType) Descriptor ¶ added in v0.0.15
func (ColAttr_VarType) Descriptor() protoreflect.EnumDescriptor
func (ColAttr_VarType) Enum ¶ added in v0.0.15
func (x ColAttr_VarType) Enum() *ColAttr_VarType
func (ColAttr_VarType) EnumDescriptor
deprecated
added in
v0.0.15
func (ColAttr_VarType) EnumDescriptor() ([]byte, []int)
Deprecated: Use ColAttr_VarType.Descriptor instead.
func (ColAttr_VarType) Number ¶ added in v0.0.15
func (x ColAttr_VarType) Number() protoreflect.EnumNumber
func (ColAttr_VarType) String ¶ added in v0.0.15
func (x ColAttr_VarType) String() string
func (ColAttr_VarType) Type ¶ added in v0.0.15
func (ColAttr_VarType) Type() protoreflect.EnumType
type Location ¶ added in v0.0.2
type Location struct {
X int64 `protobuf:"varint,1,opt,name=x,proto3" json:"x,omitempty"`
Y int64 `protobuf:"varint,2,opt,name=y,proto3" json:"y,omitempty"`
// contains filtered or unexported fields
}
used for grid layouts
func (*Location) Descriptor
deprecated
added in
v0.0.2
func (*Location) ProtoMessage ¶ added in v0.0.2
func (*Location) ProtoMessage()
func (*Location) ProtoReflect ¶ added in v0.0.2
func (x *Location) ProtoReflect() protoreflect.Message
type LocationScanner ¶ added in v0.0.11
func (*LocationScanner) Next ¶ added in v0.0.11
func (it *LocationScanner) Next() *Location
Next() returns the next thing in the array
func (*LocationScanner) Scan ¶ added in v0.0.11
func (it *LocationScanner) Scan() bool
type Size ¶ added in v0.0.2
type Size struct {
Width int64 `protobuf:"varint,1,opt,name=width,proto3" json:"width,omitempty"`
Height int64 `protobuf:"varint,2,opt,name=height,proto3" json:"height,omitempty"`
// contains filtered or unexported fields
}
func (*Size) Descriptor
deprecated
added in
v0.0.2
func (*Size) ProtoMessage ¶ added in v0.0.2
func (*Size) ProtoMessage()
func (*Size) ProtoReflect ¶ added in v0.0.2
func (x *Size) ProtoReflect() protoreflect.Message
type SizeScanner ¶ added in v0.0.11
func (*SizeScanner) Next ¶ added in v0.0.11
func (it *SizeScanner) Next() *Size
Next() returns the next thing in the array
func (*SizeScanner) Scan ¶ added in v0.0.11
func (it *SizeScanner) Scan() bool
type Table ¶ added in v0.0.2
type Table struct {
Uuid string `protobuf:"bytes,1,opt,name=uuid,proto3" json:"uuid,omitempty"`
Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
Parent *Widget `protobuf:"bytes,3,opt,name=parent,proto3" json:"parent,omitempty"`
AnyCols []*AnyCol `protobuf:"bytes,4,rep,name=anyCols,proto3" json:"anyCols,omitempty"`
Grid *Widget `protobuf:"bytes,5,opt,name=grid,proto3" json:"grid,omitempty"` // deprecate
// contains filtered or unexported fields
}
func (*Table) Descriptor
deprecated
added in
v0.0.2
func (*Table) FormatTEXT ¶ added in v0.0.2
apparently this isn't stable, but it's awesomely better https://protobuf.dev/reference/go/faq/#unstable-text it's brilliant for config files!
func (*Table) GetAnyCols ¶ added in v0.0.15
func (*Table) MarshalJSON ¶ added in v0.0.2
marshal json
func (*Table) ProtoMessage ¶ added in v0.0.2
func (*Table) ProtoMessage()
func (*Table) ProtoReflect ¶ added in v0.0.2
func (x *Table) ProtoReflect() protoreflect.Message
func (*Table) RegisterCustom ¶ added in v0.0.9
func (*Table) UnmarshalJSON ¶ added in v0.0.2
unmarshal json
func (*Table) UnmarshalTEXT ¶ added in v0.0.2
unmarshalTEXT. This reads the .text config file back in after the user edits it
type TableScanner ¶ added in v0.0.11
func (*TableScanner) Next ¶ added in v0.0.11
func (it *TableScanner) Next() *Table
Next() returns the next thing in the array
func (*TableScanner) Scan ¶ added in v0.0.11
func (it *TableScanner) Scan() bool
type Tables ¶ added in v0.0.2
type Tables struct {
Uuid string `protobuf:"bytes,1,opt,name=uuid,proto3" json:"uuid,omitempty"` // `autogenpb:uuid:c328aa62-3c4f-4d00-9244-cc44ae75ab1b`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"` // `autogenpb:version:v1`
Tables []*Table `protobuf:"bytes,3,rep,name=Tables,proto3" json:"Tables,omitempty"`
// contains filtered or unexported fields
}
func (*Tables) All ¶ added in v0.0.2
func (x *Tables) All() *TableScanner
func (*Tables) Append ¶ added in v0.0.2
a Append() shortcut (that does Clone() with a mutex) notsure if it really works doesn't allow nil
func (*Tables) Clone ¶ added in v0.0.22
a Clone() shortcut (with a mutex). notsure if it really works
func (*Tables) Descriptor
deprecated
added in
v0.0.2
func (*Tables) FormatJSON ¶ added in v0.0.2
human readable JSON
func (*Tables) FormatTEXT ¶ added in v0.0.2
apparently this isn't stable, but it's awesomely better https://protobuf.dev/reference/go/faq/#unstable-text it's brilliant for config files!
func (*Tables) GetVersion ¶ added in v0.0.2
func (*Tables) IterAll ¶ added in v0.0.10
Iterate 'for x := range' syntax using the awesome golang 1.24 'iter'
func (*Tables) MarshalJSON ¶ added in v0.0.2
marshal json
func (*Tables) ProtoMessage ¶ added in v0.0.2
func (*Tables) ProtoMessage()
func (*Tables) ProtoReflect ¶ added in v0.0.2
func (x *Tables) ProtoReflect() protoreflect.Message
func (*Tables) UnmarshalJSON ¶ added in v0.0.2
unmarshal json
func (*Tables) UnmarshalTEXT ¶ added in v0.0.2
unmarshalTEXT. This reads the .text config file back in after the user edits it
type TablesScanner ¶ added in v0.0.11
func (*TablesScanner) Next ¶ added in v0.0.11
func (it *TablesScanner) Next() *Tables
Next() returns the next thing in the array
func (*TablesScanner) Scan ¶ added in v0.0.11
func (it *TablesScanner) Scan() bool
type Widget ¶ added in v0.0.2
type Widget struct {
// Types that are assignable to Type:
//
// *Widget_Root
// *Widget_Button
// *Widget_Window
// *Widget_Tab
// *Widget_Checkbox
// *Widget_TablePB
// *Widget_Textbox
Type isWidget_Type `protobuf_oneof:"type"`
Id int64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Val *anypb.Any `protobuf:"bytes,3,opt,name=val,proto3" json:"val,omitempty"`
Type_ WidgetType `protobuf:"varint,6,opt,name=Type,proto3,enum=gitpb.WidgetType" json:"Type,omitempty"`
Location *Location `protobuf:"bytes,7,opt,name=location,proto3" json:"location,omitempty"`
Children []*Widget `protobuf:"bytes,8,rep,name=children,proto3" json:"children,omitempty"`
// contains filtered or unexported fields
}
func (*Widget) Descriptor
deprecated
added in
v0.0.2
func (*Widget) GetButton ¶ added in v0.0.11
func (x *Widget) GetButton() *Widget_Standard
func (*Widget) GetCheckbox ¶ added in v0.0.11
func (x *Widget) GetCheckbox() *Widget_Standard
func (*Widget) GetChildren ¶ added in v0.0.11
func (*Widget) GetLocation ¶ added in v0.0.2
func (*Widget) GetRoot ¶ added in v0.0.11
func (x *Widget) GetRoot() *Widget_Internal
func (*Widget) GetTab ¶ added in v0.0.11
func (x *Widget) GetTab() *Widget_Standard
func (*Widget) GetTablePB ¶ added in v0.0.11
func (*Widget) GetTextbox ¶ added in v0.0.11
func (x *Widget) GetTextbox() *Widget_Standard
func (*Widget) GetType_ ¶ added in v0.0.11
func (x *Widget) GetType_() WidgetType
func (*Widget) GetWindow ¶ added in v0.0.11
func (x *Widget) GetWindow() *Widget_Standard
func (*Widget) ProtoMessage ¶ added in v0.0.2
func (*Widget) ProtoMessage()
func (*Widget) ProtoReflect ¶ added in v0.0.2
func (x *Widget) ProtoReflect() protoreflect.Message
type WidgetScanner ¶ added in v0.0.11
func (*WidgetScanner) Next ¶ added in v0.0.11
func (it *WidgetScanner) Next() *Widget
Next() returns the next thing in the array
func (*WidgetScanner) Scan ¶ added in v0.0.11
func (it *WidgetScanner) Scan() bool
type WidgetType ¶ added in v0.0.7
type WidgetType int32
const ( WidgetType_Root WidgetType = 0 // the master 'root' node of the binary tree WidgetType_Flag WidgetType = 1 // internal use WidgetType_Window WidgetType = 2 // WidgetType_Tab WidgetType = 3 // a tab like in firefox WidgetType_Box WidgetType = 4 // must be either Vertical or Horizontal arrangment WidgetType_Group WidgetType = 5 // think 'Appetizers' on a restaurant menu WidgetType_Grid WidgetType = 6 // like drawers in a chest or post office boxes WidgetType_Button WidgetType = 7 // user can click on this WidgetType_Checkbox WidgetType = 8 // true or false WidgetType_Dropdown WidgetType = 9 // WidgetType_Combobox WidgetType = 10 // a dropdown menu that can be edited by the user WidgetType_Label WidgetType = 11 // a simple label WidgetType_Textbox WidgetType = 12 // enter text WidgetType_TablePB WidgetType = 13 // special case to allow the arbitrary GUI display of any other protobuf )
func (WidgetType) Descriptor ¶ added in v0.0.7
func (WidgetType) Descriptor() protoreflect.EnumDescriptor
func (WidgetType) Enum ¶ added in v0.0.7
func (x WidgetType) Enum() *WidgetType
func (WidgetType) EnumDescriptor
deprecated
added in
v0.0.7
func (WidgetType) EnumDescriptor() ([]byte, []int)
Deprecated: Use WidgetType.Descriptor instead.
func (WidgetType) Number ¶ added in v0.0.7
func (x WidgetType) Number() protoreflect.EnumNumber
func (WidgetType) String ¶ added in v0.0.7
func (x WidgetType) String() string
func (WidgetType) Type ¶ added in v0.0.7
func (WidgetType) Type() protoreflect.EnumType
type Widget_Button ¶ added in v0.0.11
type Widget_Button struct {
Button *Widget_Standard `protobuf:"bytes,10,opt,name=button,proto3,oneof"`
}
type Widget_Checkbox ¶ added in v0.0.11
type Widget_Checkbox struct {
Checkbox *Widget_Standard `protobuf:"bytes,13,opt,name=checkbox,proto3,oneof"`
}
type Widget_Internal ¶ added in v0.0.11
type Widget_Internal struct {
ProgName string `protobuf:"bytes,1,opt,name=progName,proto3" json:"progName,omitempty"`
// contains filtered or unexported fields
}
func (*Widget_Internal) Descriptor
deprecated
added in
v0.0.11
func (*Widget_Internal) Descriptor() ([]byte, []int)
Deprecated: Use Widget_Internal.ProtoReflect.Descriptor instead.
func (*Widget_Internal) GetProgName ¶ added in v0.0.11
func (x *Widget_Internal) GetProgName() string
func (*Widget_Internal) ProtoMessage ¶ added in v0.0.11
func (*Widget_Internal) ProtoMessage()
func (*Widget_Internal) ProtoReflect ¶ added in v0.0.11
func (x *Widget_Internal) ProtoReflect() protoreflect.Message
func (*Widget_Internal) Reset ¶ added in v0.0.11
func (x *Widget_Internal) Reset()
func (*Widget_Internal) String ¶ added in v0.0.11
func (x *Widget_Internal) String() string
type Widget_Root ¶ added in v0.0.11
type Widget_Root struct {
Root *Widget_Internal `protobuf:"bytes,9,opt,name=root,proto3,oneof"`
}
type Widget_Standard ¶ added in v0.0.11
type Widget_Standard struct {
ProgName string `protobuf:"bytes,1,opt,name=progName,proto3" json:"progName,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*Widget_Standard) Descriptor
deprecated
added in
v0.0.11
func (*Widget_Standard) Descriptor() ([]byte, []int)
Deprecated: Use Widget_Standard.ProtoReflect.Descriptor instead.
func (*Widget_Standard) GetName ¶ added in v0.0.11
func (x *Widget_Standard) GetName() string
func (*Widget_Standard) GetProgName ¶ added in v0.0.11
func (x *Widget_Standard) GetProgName() string
func (*Widget_Standard) ProtoMessage ¶ added in v0.0.11
func (*Widget_Standard) ProtoMessage()
func (*Widget_Standard) ProtoReflect ¶ added in v0.0.11
func (x *Widget_Standard) ProtoReflect() protoreflect.Message
func (*Widget_Standard) Reset ¶ added in v0.0.11
func (x *Widget_Standard) Reset()
func (*Widget_Standard) String ¶ added in v0.0.11
func (x *Widget_Standard) String() string
type Widget_Tab ¶ added in v0.0.11
type Widget_Tab struct {
Tab *Widget_Standard `protobuf:"bytes,12,opt,name=tab,proto3,oneof"`
}
type Widget_TablePB ¶ added in v0.0.11
type Widget_TablePB struct {
TablePB []byte `protobuf:"bytes,14,opt,name=tablePB,proto3,oneof"`
}
type Widget_Textbox ¶ added in v0.0.11
type Widget_Textbox struct {
Textbox *Widget_Standard `protobuf:"bytes,15,opt,name=textbox,proto3,oneof"`
}
type Widget_Window ¶ added in v0.0.11
type Widget_Window struct {
Window *Widget_Standard `protobuf:"bytes,11,opt,name=window,proto3,oneof"`
}
type Widgets ¶ added in v0.0.2
type Widgets struct {
Uuid string `protobuf:"bytes,1,opt,name=uuid,proto3" json:"uuid,omitempty"` // `autogenpb:uuid:0331fcd7-3c8c-43e4-be1b-77db6a6bc58c`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"` // `autogenpb:version:v1`
Widgets []*Widget `protobuf:"bytes,3,rep,name=Widgets,proto3" json:"Widgets,omitempty"` // this never gets used, but it's not worth violating the autogenpb standard
Tree *Widget `protobuf:"bytes,4,opt,name=tree,proto3" json:"tree,omitempty"` // everything is sent from go.wit.com/gui here
// contains filtered or unexported fields
}
func NewWidgets ¶ added in v0.0.2
func NewWidgets() *Widgets
func (*Widgets) All ¶ added in v0.0.2
func (x *Widgets) All() *WidgetScanner
func (*Widgets) Append ¶ added in v0.0.2
a Append() shortcut (that does Clone() with a mutex) notsure if it really works doesn't allow nil
func (*Widgets) Clone ¶ added in v0.0.22
a Clone() shortcut (with a mutex). notsure if it really works
func (*Widgets) Descriptor
deprecated
added in
v0.0.2
func (*Widgets) FormatJSON ¶ added in v0.0.7
human readable JSON
func (*Widgets) FormatTEXT ¶ added in v0.0.7
apparently this isn't stable, but it's awesomely better https://protobuf.dev/reference/go/faq/#unstable-text it's brilliant for config files!
func (*Widgets) GetVersion ¶ added in v0.0.2
func (*Widgets) GetWidgets ¶ added in v0.0.2
func (*Widgets) IterAll ¶ added in v0.0.10
Iterate 'for x := range' syntax using the awesome golang 1.24 'iter'
func (*Widgets) MarshalJSON ¶ added in v0.0.7
marshal json
func (*Widgets) ProtoMessage ¶ added in v0.0.2
func (*Widgets) ProtoMessage()
func (*Widgets) ProtoReflect ¶ added in v0.0.2
func (x *Widgets) ProtoReflect() protoreflect.Message
func (*Widgets) UnmarshalJSON ¶ added in v0.0.7
unmarshal json
func (*Widgets) UnmarshalTEXT ¶ added in v0.0.7
unmarshalTEXT. This reads the .text config file back in after the user edits it
type WidgetsScanner ¶ added in v0.0.11
func (*WidgetsScanner) Next ¶ added in v0.0.11
func (it *WidgetsScanner) Next() *Widgets
Next() returns the next thing in the array
func (*WidgetsScanner) Scan ¶ added in v0.0.11
func (it *WidgetsScanner) Scan() bool